Learn R Programming

Xcertainty (version 1.0.0)

body_condition_measurements: Humpback whale measurement data from Duke University's Marine Robotics and Remote Sensing (MaRRS) Lab

Description

Photogrammetric measurements of humpback whales to estimate total body length and body condition.

Usage

body_condition_measurements

Arguments

Format

A data frame with 29 rows and 28 columns:

Animal_ID

unique ID for the individual whale

TL

total body length measurement (m)

TL.10.0..Width

Width of whale (m), pre-computed from pixels using the reported laser altimeter measurement. Width is taken at a cross-section perpendicular to the whale's center line, running from the middle of the rostrum (loosely, the whale's beak/nose) to the middle of the peduncle (the point where the tail connects to the rest of the body). The cross-section is taken 10 from the animal's rostrum to its peduncle.

TL.15.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 15 to its peduncle.

TL.20.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 20 to its peduncle.

TL.25.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 25 to its peduncle.

TL.30.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 30 to its peduncle.

TL.35.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 35 to its peduncle.

TL.40.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 40 to its peduncle.

TL.45.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 45 to its peduncle.

TL.50.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 50 to its peduncle.

TL.55.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 55 to its peduncle.

TL.60.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 60 to its peduncle.

TL.65.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 65 to its peduncle.

TL.70.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 70 to its peduncle.

TL.75.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 75 to its peduncle.

TL.80.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 80 to its peduncle.

TL.85.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 85 to its peduncle.

TL.90.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 90 to its peduncle.

TL.95.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 95 to its peduncle.

TL.5.0..Width

Same as TL.10.0..Width, but taken at a cross-section that is 5 to its peduncle.

Image

image name

BaroAlt

the barometer altitude adjusted for the launch height of the drone

LaserAlt

the altitude recorded by the laser (LiDAR) altimeter

Focal_Length

focal length of the camera (mm)

Iw

image width (px)

Sw

sensor width (mm)

Aircraft

the unoccupied aircraft system (UAS), or drone, used in data collection