Learn R Programming

Xcertainty (version 1.0.0)

whale_info: Gray whale metadata

Description

Gray whale information and metadata that pairs with 'whales' data by "Subject"

Usage

whale_info

Arguments

Format

A data frame with 293 rows and 5 columns:

Year

year

Subject

unique ID for individuals

Group

sex; Male, Female (F), or NA

ObservedAge

age in years

AgeType

either 'known age' if individual was seen as a calf, or 'min age' from the date of date sighting